==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/vo/DcDrawingApplyForVO.java <==
package com.ejianc.business.dc.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 图纸申请
 *
 * @author generator
 *
 */
public class DcDrawingApplyForVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0 自由态，1 已提交，2 审批中，3 审批通过，4 驳回，5 提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long engineeringTypeId; // 工程类别ID
    private String engineeringType; // 工程类别
    private Long applyForUserId; // 申请人员id
    private String applyForUserName; // 申请人姓名
    private Long applyForDeptId; // 申请部门id
    private String applyForDeptName; // 申请部门姓名
    private String controlledDistribution; // 受控分发（1：是，0：否）
    private Integer num; // 申请份数
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private String flowState; // 流程状态--字典dc_tzk
    private String flowStateName; // 流程状态名称
    private String distCode; // 分发单号
    private String distUserCode; // 分发人编号
    private String distUserName; // 分发人姓名

    private List<DcDrawingApplyForDrwgrpVO> dcDrawingApplyForDrwgrpList = new ArrayList<>(); // 图纸申请-卷册信息

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getApplyForUserId() {
        return applyForUserId;
    }

    @ReferDeserialTransfer
    public void setApplyForUserId(Long applyForUserId) {
        this.applyForUserId = applyForUserId;
    }
    public String getApplyForUserName() {
        return applyForUserName;
    }

    public void setApplyForUserName(String applyForUserName) {
        this.applyForUserName = applyForUserName;
    }
    public Long getApplyForDeptId() {
        return applyForDeptId;
    }

    public void setApplyForDeptId(Long applyForDeptId) {
        this.applyForDeptId = applyForDeptId;
    }
    public String getApplyForDeptName() {
        return applyForDeptName;
    }

    public void setApplyForDeptName(String applyForDeptName) {
        this.applyForDeptName = applyForDeptName;
    }
    public String getControlledDistribution() {
        return controlledDistribution;
    }

    public void setControlledDistribution(String controlledDistribution) {
        this.controlledDistribution = controlledDistribution;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public List<DcDrawingApplyForDrwgrpVO> getDcDrawingApplyForDrwgrpList() {
        return dcDrawingApplyForDrwgrpList;
    }

    public void setDcDrawingApplyForDrwgrpList(List<DcDrawingApplyForDrwgrpVO> dcDrawingApplyForDrwgrpList) {
        this.dcDrawingApplyForDrwgrpList = dcDrawingApplyForDrwgrpList;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230926.062054-230-sources.jar: com/ejianc/business/dc/vo/DcDrawingApplyForVO.java <==
package com.ejianc.business.dc.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 图纸申请
 *
 * @author generator
 *
 */
public class DcDrawingApplyForVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态：0 自由态，1 已提交，2 审批中，3 审批通过，4 驳回，5 提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long engineeringTypeId; // 工程类别ID
    private String engineeringType; // 工程类别
    private Long applyForUserId; // 申请人员id
    private String applyForUserName; // 申请人姓名
    private Long applyForDeptId; // 申请部门id
    private String applyForDeptName; // 申请部门姓名
    private String controlledDistribution; // 受控分发（1：是，0：否）
    private Integer num; // 申请份数
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private String flowState; // 流程状态
    private String flowStateName; // 流程状态名称
    private String distCode; // 分发单号
    private String distUserCode; // 分发人编号
    private String distUserName; // 分发人姓名
    private Date distDate; // 分发日期

    private List<DcDrawingApplyForDrwgrpVO> dcDrawingApplyForDrwgrpList = new ArrayList<>(); // 图纸申请-卷册信息

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getApplyForUserId() {
        return applyForUserId;
    }

    @ReferDeserialTransfer
    public void setApplyForUserId(Long applyForUserId) {
        this.applyForUserId = applyForUserId;
    }
    public String getApplyForUserName() {
        return applyForUserName;
    }

    public void setApplyForUserName(String applyForUserName) {
        this.applyForUserName = applyForUserName;
    }
    public Long getApplyForDeptId() {
        return applyForDeptId;
    }

    public void setApplyForDeptId(Long applyForDeptId) {
        this.applyForDeptId = applyForDeptId;
    }
    public String getApplyForDeptName() {
        return applyForDeptName;
    }

    public void setApplyForDeptName(String applyForDeptName) {
        this.applyForDeptName = applyForDeptName;
    }
    public String getControlledDistribution() {
        return controlledDistribution;
    }

    public void setControlledDistribution(String controlledDistribution) {
        this.controlledDistribution = controlledDistribution;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public List<DcDrawingApplyForDrwgrpVO> getDcDrawingApplyForDrwgrpList() {
        return dcDrawingApplyForDrwgrpList;
    }

    public void setDcDrawingApplyForDrwgrpList(List<DcDrawingApplyForDrwgrpVO> dcDrawingApplyForDrwgrpList) {
        this.dcDrawingApplyForDrwgrpList = dcDrawingApplyForDrwgrpList;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }

    public Date getDistDate() {
        return distDate;
    }

    public void setDistDate(Date distDate) {
        this.distDate = distDate;
    }
}
